Index — django-modeltrans 0.0.4 documentation

# Index

A | G | M | T

## A

add_i18n_annotation() (modeltrans.manager.MultilingualQuerySet method)

## G

get_field_name() (modeltrans.fields.TranslatedVirtualField method) | get_language() (modeltrans.fields.TranslatedVirtualField method)

## M

MultilingualManager (class in modeltrans.manager) | MultilingualQuerySet (class in modeltrans.manager)

## T

TranslatedVirtualField (class in modeltrans.fields) | TranslationField (class in modeltrans.fields)